@@ -499,7 +499,6 @@ parse_xml (SoupMessage  *msg,
 
   if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code))
     {
-      
       g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
                    _("HTTP Error: %s"), msg->reason_phrase);
       return NULL;
@@ -509,6 +508,7 @@ parse_xml (SoupMessage  *msg,
                        msg->response_body->length,
                        "response.xml",
                        NULL,
+                       XML_PARSE_NONET |
                        XML_PARSE_NOWARNING |
                        XML_PARSE_NOBLANKS |
                        XML_PARSE_NSCLEAN |
@@ -516,8 +516,8 @@ parse_xml (SoupMessage  *msg,
                        XML_PARSE_COMPACT);
   if (doc == NULL)
     { 
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                   "%s", _("Could not parse response"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+	                   _("Could not parse response"));
       return NULL;
     }
 
@@ -525,15 +525,17 @@ parse_xml (SoupMessage  *msg,
 
   if (*root == NULL || (*root)->children == NULL)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                   "%s", _("Empty response"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+	                   _("Empty response"));
+      xmlFreeDoc (doc);
       return NULL;
     }
 
   if (strcmp ((char *) (*root)->name, name))
     {
-        g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                     "%s", _("Unexpected reply from server"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+                           _("Unexpected reply from server"));
+      xmlFreeDoc (doc);
       return NULL;
     }
 
@@ -1130,10 +1132,10 @@ stat_location (GVfsBackend  *backend,
 
   if (status != 207)
     {
-      g_set_error (error,
-                   G_IO_ERROR,
-                   http_error_code_from_status (status),
-                   "%s", msg->reason_phrase);
+      g_set_error_literal (error,
+	                   G_IO_ERROR,
+        	           http_error_code_from_status (status),
+                	   msg->reason_phrase);
 
       return FALSE;
     }
@@ -1141,9 +1143,9 @@ stat_location (GVfsBackend  *backend,
   res = stat_location_finish (msg, target_type, num_children);
 
   if (res == FALSE)
-    g_set_error (error, 
-                 G_IO_ERROR, G_IO_ERROR_FAILED,
-                 _("Response invalid"));
+    g_set_error_literal (error, 
+	                 G_IO_ERROR, G_IO_ERROR_FAILED,
+        	         _("Response invalid"));
 
   return res;
 }
