@@ -28,6 +28,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <string.h>
+#include <stdlib.h>
 
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
@@ -457,6 +458,8 @@ do_mount (GVfsBackend *backend,
   char *uri;
   int res;
   char *display_name;
+  const char *debug;
+  int debug_val;
   GMountSpec *smb_mount_spec;
   smbc_stat_fn smbc_stat;
 
@@ -470,7 +473,13 @@ do_mount (GVfsBackend *backend,
     }
   smbc_setOptionUserData (smb_context, backend);
 
-  smbc_setDebug (smb_context, 0);
+  debug = g_getenv ("GVFS_SMB_DEBUG");
+  if (debug)
+    debug_val = atoi (debug);
+  else
+    debug_val = 0;
+
+  smbc_setDebug (smb_context, debug_val);
   smbc_setFunctionAuthDataWithContext (smb_context, auth_callback);
   
   smbc_setFunctionAddCachedServer (smb_context, add_cached_server);
@@ -506,23 +515,6 @@ do_mount (GVfsBackend *backend,
 
   op_backend->smb_context = smb_context;
 
-  /* Translators: This is "<sharename> on <servername>" and is used as name for an SMB share */
-  display_name = g_strdup_printf (_("%s on %s"), op_backend->share, op_backend->server);
-  g_vfs_backend_set_display_name (backend, display_name);
-  g_free (display_name);
-  g_vfs_backend_set_icon_name (backend, "folder-remote");
-  
-  smb_mount_spec = g_mount_spec_new ("smb-share");
-  g_mount_spec_set (smb_mount_spec, "share", op_backend->share);
-  g_mount_spec_set (smb_mount_spec, "server", op_backend->server);
-  if (op_backend->user)
-    g_mount_spec_set (smb_mount_spec, "user", op_backend->user);
-  if (op_backend->domain)
-    g_mount_spec_set (smb_mount_spec, "domain", op_backend->domain);
-  
-  g_vfs_backend_set_mount_spec (backend, smb_mount_spec);
-  g_mount_spec_unref (smb_mount_spec);
-
   uri = create_smb_uri (op_backend->server, op_backend->share, NULL);
 
   op_backend->mount_source = mount_source;
@@ -559,6 +551,27 @@ do_mount (GVfsBackend *backend,
       return;
     }
 
+  /* Mount was successful */
+
+  /* Translators: This is "<sharename> on <servername>" and is used as name for an SMB share */
+  display_name = g_strdup_printf (_("%s on %s"), op_backend->share, op_backend->server);
+  g_vfs_backend_set_display_name (backend, display_name);
+  g_free (display_name);
+  g_vfs_backend_set_icon_name (backend, "folder-remote");
+
+  smb_mount_spec = g_mount_spec_new ("smb-share");
+  g_mount_spec_set (smb_mount_spec, "share", op_backend->share);
+  g_mount_spec_set (smb_mount_spec, "server", op_backend->server);
+  if (op_backend->last_user && strlen(op_backend->last_user) > 0)
+    {
+      g_mount_spec_set (smb_mount_spec, "user", op_backend->last_user);
+      if (op_backend->last_domain)
+        g_mount_spec_set (smb_mount_spec, "domain", op_backend->last_domain);
+    }
+
+  g_vfs_backend_set_mount_spec (backend, smb_mount_spec);
+  g_mount_spec_unref (smb_mount_spec);
+
   g_vfs_keyring_save_password (op_backend->last_user,
 			       op_backend->server,
 			       op_backend->last_domain,
@@ -612,17 +625,33 @@ do_open_for_read (GVfsBackend *backend,
   GVfsBackendSmb *op_backend = G_VFS_BACKEND_SMB (backend);
   char *uri;
   SMBCFILE *file;
+  struct stat st;
   smbc_open_fn smbc_open;
+  smbc_stat_fn smbc_stat;
+  int res;
+  int olderr;
+
 
   uri = create_smb_uri (op_backend->server, op_backend->share, filename);
   smbc_open = smbc_getFunctionOpen (op_backend->smb_context);
   file = smbc_open (op_backend->smb_context, uri, O_RDONLY, 0);
-  g_free (uri);
 
   if (file == NULL)
-    g_vfs_job_failed_from_errno (G_VFS_JOB (job), errno);
+    {
+      olderr = errno;
+      smbc_stat = smbc_getFunctionStat (op_backend->smb_context);
+      res = smbc_stat (op_backend->smb_context, uri, &st);
+      g_free (uri);
+      if ((res == 0) && (S_ISDIR (st.st_mode)))
+            g_vfs_job_failed (G_VFS_JOB (job),
+                              G_IO_ERROR, G_IO_ERROR_IS_DIRECTORY,
+                             _("Can't open directory"));
+      else
+        g_vfs_job_failed_from_errno (G_VFS_JOB (job), olderr);
+  }
   else
     {
+      
       g_vfs_job_open_for_read_set_can_seek (job, TRUE);
       g_vfs_job_open_for_read_set_handle (job, file);
       g_vfs_job_succeeded (G_VFS_JOB (job));
@@ -986,9 +1015,9 @@ do_replace (GVfsBackend *backend,
     {
       int errsv = errno;
 
-      g_set_error (&error, G_IO_ERROR,
-		   g_io_error_from_errno (errsv),
-		   "%s", g_strerror (errsv));
+      g_set_error_literal (&error, G_IO_ERROR,
+			   g_io_error_from_errno (errsv),
+			   g_strerror (errsv));
       goto error;
     }
   else if (file == NULL && errno == EEXIST)
@@ -1003,11 +1032,10 @@ do_replace (GVfsBackend *backend,
 	      if (strcmp (etag, current_etag) != 0)
 		{
 		  g_free (current_etag);
-		  g_set_error (&error,
-			       G_IO_ERROR,
-			       G_IO_ERROR_WRONG_ETAG,
-			       "%s",
-                               _("The file was externally modified"));
+		  g_set_error_literal (&error,
+				       G_IO_ERROR,
+				       G_IO_ERROR_WRONG_ETAG,
+                	               _("The file was externally modified"));
 		  goto error;
 		}
 	      g_free (current_etag);
@@ -1035,17 +1063,15 @@ do_replace (GVfsBackend *backend,
 	      if (!copy_file (op_backend, G_VFS_JOB (job), uri, backup_uri))
 		{
 		  if (g_vfs_job_is_cancelled (G_VFS_JOB (job)))
-		    g_set_error (&error,
-				 G_IO_ERROR,
-				 G_IO_ERROR_CANCELLED,
-                                 "%s",
-				 _("Operation was cancelled"));
+		    g_set_error_literal (&error,
+					 G_IO_ERROR,
+					 G_IO_ERROR_CANCELLED,
+					 _("Operation was cancelled"));
 		  else
-		    g_set_error (&error,
-				 G_IO_ERROR,
-				 G_IO_ERROR_CANT_CREATE_BACKUP,
-                                 "%s",
-				 _("Backup file creation failed"));
+		    g_set_error_literal (&error,
+					 G_IO_ERROR,
+					 G_IO_ERROR_CANT_CREATE_BACKUP,
+					 _("Backup file creation failed"));
 		  goto error;
 		}
 	      g_free (backup_uri);
@@ -1058,9 +1084,9 @@ do_replace (GVfsBackend *backend,
 	    {
               int errsv = errno;
 
-	      g_set_error (&error, G_IO_ERROR,
-			   g_io_error_from_errno (errsv),
-			   "%s", g_strerror (errsv));
+	      g_set_error_literal (&error, G_IO_ERROR,
+				   g_io_error_from_errno (errsv),
+				   g_strerror (errsv));
 	      goto error;
 	    }
 	}
@@ -1511,9 +1537,9 @@ do_enumerate (GVfsBackend *backend,
       int errsv = errno;
 
       error = NULL;
-      g_set_error (&error, G_IO_ERROR,
-		   g_io_error_from_errno (errsv),
-		   "%s", g_strerror (errsv));
+      g_set_error_literal (&error, G_IO_ERROR,
+			   g_io_error_from_errno (errsv),
+			   g_strerror (errsv));
       goto error;
     }
 
